@@ -3,8 +3,9 @@ from abc import abstractmethod
 from pydantic import BaseModel
 from pyro_client.client.file import FileClient
 from x_client.aiohttp import Client as HttpClient
+from xync_bot import XyncBot
 from xync_schema import models
-from xync_schema.models import OrderStatus, Coin, Cur, Ad, AdStatus, Actor
+from xync_schema.models import OrderStatus, Coin, Cur, Ad, AdStatus, Actor, Agent
 from xync_schema.xtype import BaseAd
 
 from xync_client.Abc.Ex import BaseExClient
@@ -12,10 +13,23 @@ from xync_client.Abc.xtype import CredExOut, BaseOrderReq, BaseAdUpdate
 
 
 class BaseAgentClient(HttpClient):
-    def __init__(self, actor: Actor, bot: FileClient, headers: dict[str, str] = None, cookies: dict[str, str] = None):
-        self.actor: Actor = actor
-        super().__init__(actor.ex.host_p2p, headers, cookies)
-        self.ex_client: BaseExClient = self.actor.ex.client(bot)
+    bbot: XyncBot
+    fbot: FileClient
+
+    def __init__(
+        self,
+        agent: Agent,
+        fbot: FileClient,
+        bbot: XyncBot,
+        headers: dict[str, str] = None,
+        cookies: dict[str, str] = None,
+    ):
+        self.bbot = bbot
+        self.fbot = fbot
+        self.agent: Agent = agent
+        self.actor: Actor = agent.actor
+        super().__init__(self.actor.ex.host_p2p, headers, cookies)
+        self.ex_client: BaseExClient = self.actor.ex.client(fbot)
 
     # 0: Получшение ордеров в статусе status, по монете coin, в валюте coin, в направлении is_sell: bool
     @abstractmethod
