@@ -24,10 +24,11 @@ from tortoise.signals import post_save
 from urllib3.exceptions import ReadTimeoutError
 from x_model import init_db
 from x_model.func import ArrayAgg
+from xync_bot import XyncBot
 from xync_schema import models
 from xync_schema.enums import OrderStatus
 
-from xync_schema.models import Actor, Cond, CondSim, PmCur, PairSide
+from xync_schema.models import Actor, Cond, CondSim, PmCur, PairSide, Agent
 
 from xync_client.Abc.Agent import BaseAgentClient
 from xync_client.Abc.xtype import BaseOrderReq, FlatDict
@@ -43,7 +44,7 @@ from xync_client.Bybit.etype.order import (
     Message,
     Status,
 )
-from xync_client.loader import TORM, NET_TOKEN
+from xync_client.loader import TORM, NET_TOKEN, PAY_TOKEN
 
 
 class NoMakerException(Exception):
@@ -87,9 +88,9 @@ class AgentClient(BaseAgentClient):  # Bybit client
     rcond_sims: dict[int, set[int]] = defaultdict(set)  # backward
     tree: dict = {}
 
-    def __init__(self, actor: Actor, bot: FileClient, **kwargs):
-        super().__init__(actor, bot, **kwargs)
-        self.api = P2P(testnet=False, api_key=actor.agent.auth["key"], api_secret=actor.agent.auth["sec"])
+    def __init__(self, agent: Agent, fbot: FileClient, bbot: XyncBot, **kwargs):
+        super().__init__(agent, fbot, bbot, **kwargs)
+        self.api = P2P(testnet=False, api_key=agent.auth["key"], api_secret=agent.auth["sec"])
         self.hist: dict = None
         self.completed_orders: list[int] = None
 
@@ -1248,7 +1249,7 @@ class ExcCode(IntEnum):
 
 async def main():
     logging.basicConfig(level=logging.INFO)
-    _ = await init_db(TORM)
+    cn = await init_db(TORM)
 
     @post_save(models.Race)
     async def race_upserted(
@@ -1262,12 +1263,14 @@ async def main():
             ...
 
     actor = (
-        await models.Actor.filter(ex_id=4, agent__isnull=False).prefetch_related("ex", "agent", "person__user").first()
+        await models.Agent.filter(actor__ex_id=4, auth__isnull=False, active=True)
+        .prefetch_related("actor__ex", "actor__person__user")
+        .first()
     )
     filebot = FileClient(NET_TOKEN)
     await filebot.start()
     # b.add_handler(MessageHandler(cond_start_handler, command("cond")))
-    cl: AgentClient = actor.client(filebot)
+    cl: AgentClient = actor.client(filebot, XyncBot(PAY_TOKEN, cn))
 
     # await cl.ex_client.set_pairs()
     # await cl.ex_client.set_pms()
