@@ -31,12 +31,16 @@ class Status(IntEnum):
 
 class StatusApi(IntEnum):
     created = 1
+    _web3 = 5
     wait_for_buyer = 10  # ws_canceled
     wait_for_seller = 20
     appealed = 30
     canceled = 40
     completed = 50
+    _paying_online = 60
+    _pay_fail_online = 70
     hotswap_cancelled = 80
+    _buyer_sel_tokenId = 90
     objectioning = 100
     waiting_for_objection = 110
 
@@ -290,18 +294,18 @@ class Message(BaseModel):
     nickName: str
     read: Literal[0, 1]
     fileName: str
-    onlyForCustomer: int
+    onlyForCustomer: int | None = None
 
 
 class _BaseChange(BaseModel):
     userId: int
     makerUserId: int
     id: str
-    status: StatusApi
     createDate: int
     side: int
     appealedTimes: int
     totalAppealedTimes: int
+    status: StatusApi | None = None
 
 
 class StatusChange(_BaseChange):
@@ -320,18 +324,18 @@ class _BaseMsg(BaseModel):
     msgUuId: str
     createDate: str
     contentType: str
-    roleType: Literal["user", "sys", "alarm"]
+    roleType: Literal["user", "sys", "alarm", "customer_support"]
 
 
 class Receive(_BaseMsg):
     id: int
     msgCode: int
-    onlyForCustomer: int
+    onlyForCustomer: int | None = None
 
 
 class Read(_BaseMsg):
     readAmount: int
-    read: Literal["111", "101"]
+    read: Literal["101", "110", "11", "111"]
     orderStatus: StatusApi
 
 
