@@ -7,7 +7,7 @@ from xync_schema import models, xtype
 from xync_schema.models import Ex, Agent
 
 from xync_client.Abc.Ex import BaseExClient
-from xync_client.loader import TOKEN
+from xync_client.loader import NET_TOKEN
 from xync_client.Bybit.etype import ad
 from xync_client.Abc.xtype import PmEx, MapOfIdsList
 from xync_client.loader import TORM
@@ -114,10 +114,10 @@ class ExClient(BaseExClient):  # Bybit client
 async def main():
     _ = await init_db(TORM, True)
     ex = await Ex.get(name="Bybit")
-    bot: FileClient = FileClient(TOKEN)
+    bot: FileClient = FileClient(NET_TOKEN)
     # await bot.start()
     cl = ExClient(ex, bot)
-    # await cl.set_pms()
+    await cl.set_pms()
     await cl.set_coins()
     await cl.set_pairs()
     _ads = await cl.ads("USDT", "GEL", False)
