@@ -6,7 +6,7 @@ from xync_schema.models import Ex
 from xync_schema import xtype
 
 from xync_client.Abc.Ex import BaseExClient
-from xync_client.loader import TOKEN, TORM
+from xync_client.loader import NET_TOKEN, TORM
 from xync_client.Abc.xtype import PmEx, MapOfIdsList
 from xync_client.Gate.etype import ad
 
@@ -93,7 +93,7 @@ class ExClient(BaseExClient):
 async def main():
     _ = await init_db(TORM, True)
     gt = await Ex.get(name="Gate")
-    async with FileClient(TOKEN) as b:
+    async with FileClient(NET_TOKEN) as b:
         cl = ExClient(gt, b)
         await cl.set_pairs()
         pms = await cl.set_coins()
