@@ -2,7 +2,7 @@ from asyncio import run
 
 from pyro_client.client.file import FileClient
 from x_model import init_db
-from xync_client.loader import TORM, TOKEN
+from xync_client.loader import TORM, NET_TOKEN
 from xync_schema import models
 from xync_schema import xtype
 
@@ -80,7 +80,7 @@ class ExClient(BaseExClient):
 async def main():
     _ = await init_db(TORM, True)
     bg = await models.Ex.get(name="KuCoin")
-    async with FileClient(TOKEN) as b:
+    async with FileClient(NET_TOKEN) as b:
         cl: ExClient = bg.client(b)
         await cl.set_pms()
         await cl.set_coins()
