@@ -3,7 +3,7 @@ from asyncio import run
 from pyro_client.client.file import FileClient
 from x_model import init_db
 import requests
-from xync_client.loader import TORM, TOKEN
+from xync_client.loader import TORM, NET_TOKEN
 
 from xync_client.Abc.Ex import BaseExClient
 from xync_client.Abc.xtype import PmEx, MapOfIdsList
@@ -90,7 +90,7 @@ class ExClient(BaseExClient):
 
 async def main():
     _ = await init_db(TORM)
-    async with FileClient(TOKEN) as b:
+    async with FileClient(NET_TOKEN) as b:
         ex = await Ex.get(name="Mexc")
         cl = ex.client(b)
         # await ex.curexs.filter(cur__ticker="EUR")
