@@ -12,7 +12,7 @@ async def login(agent: PmAgent):
     options.add_argument("--disable-blink-features=AutomationControlled")
     options.add_argument("--no-sandbox")
     options.add_argument("--disable-dev-shm-usage")
-    options.add_argument("--headless=new")  # for Chrome >= 109
+    # options.add_argument("--headless=new")  # for Chrome >= 109
     options.add_argument("--disable-renderer-backgrounding")
     options.add_argument("--disable-background-timer-throttling")
     options.add_argument("--disable-backgrounding-occluded-windows")
@@ -28,7 +28,11 @@ async def login(agent: PmAgent):
     options.add_argument("--window-size=1920,1080")
     options.add_argument("--user-agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36")
 
-    driver = uc.Chrome(options=options, headless=True)
+    driver = uc.Chrome(
+        options=options,
+        headless=False,
+        browser_executable_path="/Applications/Google Chrome Beta.app/Contents/MacOS/Google Chrome Beta",
+    )
     wait = WebDriverWait(driver, timeout=10)
     try:
         driver.get("https://payeer.com/en/auth")
